@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | eAccelerator project                                                 |
    +----------------------------------------------------------------------+
-   | Copyright (c) 2004 - 2006 eAccelerator                               |
+   | Copyright (c) 2004 - 2010 eAccelerator                               |
    | http://eaccelerator.net                                              |
    +----------------------------------------------------------------------+
    | This program is free software; you can redistribute it and/or        |
@@ -22,7 +22,7 @@
    |                                                                      |
    | A copy is availble at http://www.gnu.org/copyleft/gpl.txt            |
    +----------------------------------------------------------------------+
-   $Id: mm.c 176 2006-03-05 12:18:54Z bart $
+   $Id: mm.c 401 2010-02-04 18:00:07Z bart $
 */
 
 /* libmm replacement */
@@ -44,10 +44,6 @@
 #  endif
 #endif
 
-#if !defined(MM_TEST_SEM) && !defined(MM_TEST_SHM)
-# include "debug.h"
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
@@ -70,6 +66,9 @@
 #  endif
 #endif
 
+#undef MM_CHECK 
+#define MM_PATTERN  0xdeadbeef
+
 #if defined(MM_SHM_MMAP_FILE) || defined(MM_SHM_MMAP_ZERO) || defined(MM_SHM_MMAP_ANON) || defined(MM_SHM_MMAP_POSIX) || defined(HAVE_MPROTECT)
 #  include <sys/mman.h>
 #endif
@@ -129,6 +128,10 @@ typedef union mm_mem_head {
 #define MM_PRIVATE
 #include "mm.h"
 
+#if !defined(MM_TEST_SEM) && !defined(MM_TEST_SHM)
+# include "debug.h"
+#endif
+
 typedef union mm_word {
   size_t size;
   void*  ptr;
@@ -174,12 +177,15 @@ static int strxcat(char* dst, const char* src, int size) {
 
 #if defined(MM_SEM_SPINLOCK)
 
-#if defined(__GNUC__) && (defined(__i386__) || defined(__x86_64__))
-#  include "x86_spinlocks.h"
-#else
+#if !((defined(__GNUC__) || !defined(__SUNPRO_C)) && \
+    (defined(__i386__) || defined(__i386) || defined(__x86_64__)))
 #  error "spinlocks are not implemented for your system"
 #endif
 
+#ifndef _POSIX_PRIORITY_SCHEDULING
+#  error "Spinlocks require a working sched_yield implementation"
+#endif
+
 /*********************************/
 /* Semaphores                    */
 /********************************/
@@ -190,28 +196,44 @@ static int strxcat(char* dst, const char* src, int size) {
 #define MM_SEM_CAN_ATTACH
 
 typedef struct mm_mutex {
-  spinlock_t spinlock;
+    volatile unsigned int lock;
+    volatile pid_t pid;
+    volatile int locked;
 } mm_mutex;
 
-/* not used 
-static int mm_attach_lock(const char* key, mm_mutex* lock) {
-  return 1;
-}
-*/
+#define spinlock_try_lock(rw)  asm volatile("lock ; decl %0" :"=m" ((rw)->lock) : : "memory")
+#define _spinlock_unlock(rw)   asm volatile("lock ; incl %0" :"=m" ((rw)->lock) : : "memory")
 
-static int mm_init_lock(const char* key, mm_mutex* lock) {
-  spinlock_init(&lock->spinlock);
-  return 1;
+static int mm_init_lock(const char* key, mm_mutex* lock) 
+{
+    lock->lock = 0x1;
+    lock->pid = -1;
+    lock->locked = 0;
+    return 1;
 }
 
-static int mm_do_lock(mm_mutex* lock, int kind) {
-  spinlock_lock(&lock->spinlock);
-  return 1;
+static int mm_do_lock(mm_mutex* lock, int kind) 
+{
+    while (1) {
+        spinlock_try_lock(lock);
+        if (lock->lock == 0) {
+            lock->pid = getpid();
+            lock->locked = 1;
+            return 1;
+        }
+        _spinlock_unlock(lock);
+        sched_yield();
+    }
+    return 1;
 }
 
 static int mm_do_unlock(mm_mutex* lock) {
-  spinlock_unlock(&lock->spinlock);
-  return 1;
+    if (lock->locked && (lock->pid == getpid())) {
+        lock->pid = 0;
+        lock->locked = 0;
+        _spinlock_unlock(lock);
+    }
+    return 1;
 }
 
 static void mm_destroy_lock(mm_mutex* lock) {
@@ -265,7 +287,7 @@ static void mm_destroy_lock(mm_mutex* lock) {
 
 #elif defined(MM_SEM_POSIX)
 
-/* not tested */
+/* this one doesn't work! */
 
 #define MM_SEM_TYPE "posix"
 
@@ -274,19 +296,24 @@ typedef struct mm_mutex {
 } mm_mutex;
 
 static int mm_init_lock(const char* key, mm_mutex* lock) {
+  int fd;
 #ifdef SEM_NAME_LEN
   char s[SEM_NAME_LEN];
 
-  strncpy(s,key,SEM_NAME_LEN-1);
-  strxcat(s,".sem.XXXXXX",SEM_NAME_LEN);
+  strncpy(s, key, SEM_NAME_LEN - 1);
+  strxcat(s, ".sem.XXXXXX", SEM_NAME_LEN);
 #else
   char s[MAXPATHLEN];
 
-  strncpy(s,key,MAXPATHLEN-1);
-  strxcat(s,".sem.XXXXXX",MAXPATHLEN);
+  strncpy(s, key, MAXPATHLEN - 1);
+  strxcat(s, ".sem.XXXXXX", MAXPATHLEN);
 #endif
-  if (mktemp(s) == NULL) return 0;
+  if (mkstemp(s) == NULL) {
+    perror(s);
+    return 0;
+  }
   if ((lock->sem = sem_open(s, O_CREAT, S_IRUSR | S_IWUSR, 1)) == (sem_t*)SEM_FAILED) {
+    perror(s);
     return 0;
   }
   sem_unlink(s);
@@ -802,7 +829,7 @@ static MM* mm_create_shm(const char* key, size_t size) {
 
   strncpy(s,key,MAXPATHLEN-1);
   strxcat(s,".shm.XXXXXX",MAXPATHLEN);
-  if (mktemp(s) == NULL) {
+  if (mkstemp(s) == -1) {
     return (MM*)-1;
   }
   if ((fd = shm_open(s, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR)) == -1) {
@@ -1047,6 +1074,9 @@ void* mm_malloc_nolock(MM* mm, size_t size) {
   if (size > 0) {
     mm_mem_head* x = NULL;
     size_t realsize = (size_t)MM_ALIGN(MM_SIZE(size));
+#if MM_CHECK
+    realsize += (size_t)MM_ALIGN(sizeof(int));
+#endif
     if (realsize <= mm->available) {
       /* Search for free bucket */
       mm_free_bucket* p = mm->free_list;
@@ -1065,7 +1095,7 @@ void* mm_malloc_nolock(MM* mm, size_t size) {
           }
           break;
         } else if (p->size > realsize && (best == NULL || best->size > p->size)) {
-          /* Found best bucket (smallest bucket with the grater size) */
+          /* Found best bucket (smallest bucket with the bigger size) */
           best = p;
           best_prev = q;
         }
@@ -1100,6 +1130,9 @@ void* mm_malloc_nolock(MM* mm, size_t size) {
       }
     }
     if (x != NULL) {
+#ifdef MM_CHECK
+      *(int *)((char *)x + realsize - (size_t)MM_ALIGN(sizeof(int))) = MM_PATTERN;
+#endif
       return HEAD_TO_PTR(x);
     }
   }
@@ -1300,6 +1333,17 @@ int mm_protect(MM* mm, int mode) {
   return 0;
 }
 
+#if defined(MM_CHECK) && !(defined(MM_TEST_SHM) || defined(MM_TEST_SEM))
+void mm_check_mem(void *x) {
+  mm_mem_head *p = PTR_TO_HEAD(x);
+  if (*((unsigned int *)((char *)p + p->size - (size_t)MM_ALIGN(sizeof(int)))) != MM_PATTERN) {
+    ea_debug_error("[EACCELERATOR] Corrupted memory detected\n");
+  }
+}
+#else
+void mm_check_mem(void *x) {}
+#endif
+
 #ifdef MM_TEST_SHM
 int main() {
   char key[] = "/tmp/mm";
